/*******************************************************************
#
# This file is subject to the terms and conditions of the GNU General Public
# License.  See the file "COPYING" in ../ directory of this archive
# for more details.
#

  volume: Program to control volume of the sound device
  Usage:
     volume N     where N is left and right vol. (between 0 and 100) 
     volume L R   where L, R are separate left and right vol. (between 0 and 100) 

 Returns:
     -1 if error
     0 if no-error

NOTE: DO NOT CHANGE THE PRINTFs - being used by MAX in is TCL program
*******************************************************************/

#include <asm/io.h>
/* #include <linux/ioport.h> */
/* #include <linux/ioctl.h> */
/* #include <sys/ioctl.h> */
#include <sys/soundcard.h>

#define MAX_MIXDEVS 32

int main (int argc, char *argv[])
{
  int  fd;
  unsigned int volLeft,volRight,volume;
  unsigned int devmask;
  int device_num = 0;
  int read_only = 0;
  int i;
  int devicework;
 
  switch (argc) {
  case 1:          /* no arguments - read only */
    read_only = 1;
    break;
  case 2:     /* 1 arg. 1 volume specified - assume  left and right are same */
    if (argv[1][0] == '?') {
      printf(" Usage:\n\tvolume N\n\tvolume L R\n where N=Left/right(0-100), L=left(0-127), R=right(0-127) volumes\n");
      return -1;
    }
    volLeft = atoi(argv[1]) % 101;
    volRight = volLeft;
    break;
  case 3:    /* 2 args. left and right vol. specified */
    volLeft = atoi(argv[1]) % 101;
    volRight = atoi(argv[2]) % 101;
    break;
  default:
    printf(" Usage:\n\tvolume N\n\tvolume L R\n where N=Left/right(0-100), L=left(0-127), R=right(0-127) volumes\n");
    return -1;
    break;
  }  /* end switch */

  /* open device */
  if ((fd = open("/dev/mixer", O_RDWR)) < 0) {
    printf (" Oops, can't open /dev/mixer \n");
    return -1;  /* Error */
  }


  if (ioctl(fd, SOUND_MIXER_READ_DEVMASK, &devmask) == -1) {
    printf (" Oops, can't read devmask\n");
    return -1;
  }
  devicework = devmask;
  /*  printf ("devmask = 0x%x\n", devmask); */
  for (i=0 ; i <= MAX_MIXDEVS; i++) {
    if ( (devicework & 1) == 1 ) {
      device_num = i;
      /* printf("device_num = %d\n", device_num); */
      break;
    }
    devicework = (devicework>>1);
  }

  /* read volume */
  if (ioctl(fd, MIXER_READ( device_num ), &volume) == -1) {
    printf (" Oops, can't read mixer \n");
    return -1; /* cannot read mixer */
  }
  
  if (read_only) {
    volLeft  = volume & 0x7f;
    volRight = (volume>>8) & 0x7f;
    printf("Vol Left = %d, right=%d\n", volLeft, volRight );
    close(fd);
    return 0;
  } 

  volume = (volLeft & 0x7f) | ((volRight & 0x7f) << 8);
  printf("Setting Vol. left=%d, right=%d\n", volLeft, volRight);
  if (ioctl(fd, MIXER_WRITE(device_num), &volume) == -1) {
    printf (" Oops, can't write mixer \n");
    return -1;
  }
  
  /* re-read volume after write */
  if (ioctl(fd, MIXER_READ( device_num ), &volume) == -1) {
    printf (" Oops, can't re-read mixer \n");
    return -1; /* cannot read mixer */
  }
  volLeft  = volume & 0x7f;
  volRight = (volume>>8) & 0x7f;
  printf("New Vol Left = %d, right=%d\n", volLeft, volRight );

  /* close device */
  close(fd);
  
  return 0;  /* return new volume */
  
}
