#!/bin/sh
# Script to create and tailor for Redhat 6.1 Linux NetworkStation boot from selected rpms
# Last edited: 3/01/00
# Command:
#  rh61_create_nt_bootdir_from_rpm.sh <server-IP - mandatory> <optional boot-dir - default = /nstation/linux> 

set +x

# Set the dir name of nc specific file - could be in tmp if tmp is a RAM disk, or could
#  be in tmp.nc for nc specific files - Whatever is done here must match between 
#  create_bootdir_from_rpm script file and rc.sysinit.IBM_NS.sboot files
#  script
TMP_RAM_DIR=tmp


if [ x$1 = x"?" -o x$1 = x ]; then
  echo "Command for NetworkStation server-boot Linux Redhat6.1 client is as follows:"
  echo "rh61_create_bootdir_from_rpm.sh <server-IP address>  <client BOOT-DIR - optional>"
  echo "   default client-boot-directory is /nstation/linux"
  exit
fi

# set the IP address
IP=$1

# set BOOT_DIR
DEFAULT_BOOT_DIR_SEL=n
BOOT_DIR=$2
if [ -z "$BOOT_DIR" ]; then
  BOOT_DIR=/nstation/linux
  DEFAULT_BOOT_DIR_SEL=y
fi

current_dir=`pwd`

# Check if CDROM is mounted and files are present - CHECK if its Redhat 6.1 CD ???
if [ -d /mnt/cdrom/RedHat/RPMS ]; then
  echo ""
else
  echo ""
  echo "ERROR: No RedHat 6.1 CD - please insert the CD now and rerun this script"
  echo ""
  exit
fi

echo "Installation of Server Boot Linux Redhat 6.1 client for IBM NetworkStation... start "
echo "Current selection: " 
if [ $DEFAULT_BOOT_DIR_SEL = "y" ]; then
  echo "   Client boot directory (DEFAULT): " $BOOT_DIR
else
  echo "   Client boot directory (USER SPECIFIED): " $BOOT_DIR
fi
#echo current_dir $current_dir
echo "   Server IP address: " $IP

echo "Do you want to continue - (y/n) ?  "
read input
if [ x$input != x"y" -a x$input != x"Y" ]; then
  exit
fi

# ============  Create infrastructure for RPM installation  =================
# create the boot dir - do we need to check is boot image has already been created
../scripts/mkdirhier  ${BOOT_DIR}
../scripts/mkdirhier  ${BOOT_DIR}/var/lib/rpm
mkdir  ${BOOT_DIR}/var/tmp
# Specific for NT only 
ln -sf /tmp/packages.rpm  ${BOOT_DIR}/var/lib/rpm/packages.rpm

# ============  Install RPMS from a shell script =================
if [ ! -f ./rh61_rpm.list ]; then
   echo "ERROR: No rpm list for Redhat 6.1 distribution - Check the package "
   exit
fi
awk -f../scripts/create_rpm_script_awk -vROOT=$BOOT_DIR -vRPM_DIR="/mnt/cdrom/RedHat/RPMS/"  ./rh61_rpm.list > ./rh61_rpm.sh
chmod a+x ./rh61_rpm.sh 
echo "INSTALL RPMS - ITERATION # 1 (THIS WILL TAKE APPROXIMATELY TIME 10 MINUTES) ... "
./rh61_rpm.sh 

# remove /boot directory
rm -rf $BOOT_DIR/boot


# ============ Create  /etc/fstab file  ========================
echo "Create " $BOOT_DIR"/etc/fstab file"
if [ -f $BOOT_DIR/etc/fstab.org ]; then
  echo $BOOT_DIR/etc/fstab.org file already exists
else
  if [ -f $BOOT_DIR/etc/fstab ]; then
    mv $BOOT_DIR/etc/fstab $BOOT_DIR/etc/fstab.org
  fi
fi
echo "## Generated for IBM Network Station " > $BOOT_DIR/etc/fstab
echo $IP:$BOOT_DIR " /  nfs  defaults  1 1" >> $BOOT_DIR/etc/fstab
echo "none   /proc  proc     defaults  0 0" >> $BOOT_DIR/etc/fstab
echo "none   /dev/pts   devpts  gid=5,mode=620  0 0" >> $BOOT_DIR/etc/fstab

# ============ Modify /etc/inittab file  ========================
echo Modify $BOOT_DIR/etc/inittab to call rc.sysinit.IBM_NS
if [ -f $BOOT_DIR/etc/inittab.org ]; then
  echo $BOOT_DIR/etc/inittab.org file already exists
else
  mv $BOOT_DIR/etc/inittab $BOOT_DIR/etc/inittab.org
fi
awk -f../scripts/inittab_awk -vREPLACE="rc.sysinit" -vBY="rc.sysinit.IBM_NS.sboot"  $BOOT_DIR/etc/inittab.org > $BOOT_DIR/etc/inittab

# For GUI-login - currently commented out, until we have menu options for GUI-login
#cp $BOOT_DIR/etc/inittab  $BOOT_DIR/etc/inittab.tmp
#awk -f../scripts/inittab_awk  -vREPLACE="id:3:initdefault:" -vBY="id:5:initdefault:"  $BOOT_DIR/etc/inittab.tmp > $BOOT_DIR/etc/inittab

# =====================================================================================
#   Rename unneeded services  
# =====================================================================================
echo "Rename unneeded services during client boot"
#if [ -f $BOOT_DIR/etc/rc.d/init.d/network ]; then
#  mv  $BOOT_DIR/etc/rc.d/init.d/network  $BOOT_DIR/etc/rc.d/init.d/network.sav
#fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/atd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/atd      $BOOT_DIR/etc/rc.d/init.d/atd.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/apmd ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/apmd      $BOOT_DIR/etc/rc.d/init.d/apmd.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/kudzu ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/kudzu    $BOOT_DIR/etc/rc.d/init.d/kudzu.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/crond ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/crond    $BOOT_DIR/etc/rc.d/init.d/crond.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/nfs ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/nfs    $BOOT_DIR/etc/rc.d/init.d/nfs.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/syslog ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/syslog    $BOOT_DIR/etc/rc.d/init.d/syslog.sav
fi
if [ -f $BOOT_DIR/etc/rc.d/init.d/sendmail ]; then
  mv  $BOOT_DIR/etc/rc.d/init.d/sendmail    $BOOT_DIR/etc/rc.d/init.d/sendmail.sav
fi

# =====================================================================================
#   Add new files
# =====================================================================================
echo "Add new files - Redhat 6.1 specific files "
cp -pR SPECIFIC_BASE_CHANGES/*  $BOOT_DIR
echo "Add new files - Common distribution files "
cp -pR ../COMMON_BASE_CHANGES/*  $BOOT_DIR
mkdir -p $BOOT_DIR/$TMP_RAM_DIR
chmod a+w $BOOT_DIR/$TMP_RAM_DIR


# =====================================================================================
#   Link files directories to TMP_RAM_DISK - these are uniques file for each client
# =====================================================================================
echo "Link files to Ram disk"
# ==== Create link for var directory (created in RAM disk in /$TMP_RAM_DIR)  =======
#Link var directory - var created in ram disk under /$TMP_RAM_DIR
if [ -d $BOOT_DIR/var.nc_shared ]; then
  echo "Original var backup already present"
else
  echo "Backup var directory"
  mv $BOOT_DIR/var $BOOT_DIR/var.nc_shared
fi
ln -sf /$TMP_RAM_DIR/var $BOOT_DIR/var

#==== Link files used for networking
ln -sf /$TMP_RAM_DIR/HOSTNAME     $BOOT_DIR/etc/HOSTNAME
ln -sf /$TMP_RAM_DIR/hosts        $BOOT_DIR/etc/hosts
ln -sf /$TMP_RAM_DIR/resolv.conf  $BOOT_DIR/etc/resolv.conf
ln -sf /$TMP_RAM_DIR/network      $BOOT_DIR/etc/sysconfig/network

#==== Link mouse driver
if [ -f $BOOT_DIR/dev/mouse ]; then
  rm $BOOT_DIR/dev/mouse 
fi
ln -sf /$TMP_RAM_DIR/mouse  $BOOT_DIR/dev/mouse 

#==== Link /etc/mtab file 
if [ -f $BOOT_DIR/etc/mtab ]; then
  rm $BOOT_DIR/etc/mtab
fi
ln -sf /$TMP_RAM_DIR/mtab $BOOT_DIR/etc/mtab


# =====================================================================================
#   Set-up Xserver files for FrameBuffer or SVGA 
# =====================================================================================
XSERVER=FBUF
if [ $XSERVER = "SVGA" ]; then
  echo "Setup Xserver files - XF86_SVGA and XF86Config"
  cp  ../XSERVER_CHANGES/XF86Config.SVGA    $BOOT_DIR/etc/X11/
  cp  ../XSERVER_CHANGES/XF86_SVGA          $BOOT_DIR/usr/X11R6/bin/
  if [ -f $BOOT_DIR/etc/X11/XF86Config.org ]; then
     echo "XF86Config.org already exists - no need to backup original"
  else
    if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
      mv $BOOT_DIR/etc/X11/XF86Config  $BOOT_DIR/etc/X11/XF86Config.org
    fi
  fi
  if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
    rm $BOOT_DIR/etc/X11/XF86Config
  fi
  ln -sf XF86Config.SVGA   $BOOT_DIR/etc/X11/XF86Config
  mv $BOOT_DIR/etc/X11/X $BOOT_DIR/etc/X11/X.org
  ln -sf /usr/X11R6/bin/XF86_SVGA  $BOOT_DIR/etc/X11/X             

else             

  ## For Frame buffer  ###
  echo "Setup Xserver files - XF86_FBDev and XF86Config"
  cp  ../XSERVER_CHANGES/XF86Config.FBDev.2800    $BOOT_DIR/etc/X11/
  cp  ../XSERVER_CHANGES/XF86Config.FBDev.2200    $BOOT_DIR/etc/X11/
  if [ -f $BOOT_DIR/etc/X11/XF86Config.org ]; then
     echo "XF86Config.org already exists - no need to backup original"
  else
    if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
      mv $BOOT_DIR/etc/X11/XF86Config  $BOOT_DIR/etc/X11/XF86Config.org
    fi
  fi
  if [ -f $BOOT_DIR/etc/X11/XF86Config ]; then
    rm $BOOT_DIR/etc/X11/XF86Config
  fi
  ln -sf /$TMP_RAM_DIR/XF86Config  $BOOT_DIR/etc/X11/XF86Config
  ln -sf XF86Config.FBDev.2800 $BOOT_DIR/etc/X11/XF86Config.2800
  ln -sf XF86Config.FBDev.2200 $BOOT_DIR/etc/X11/XF86Config.2200

  # Link appropriate Xserver files
  mv $BOOT_DIR/etc/X11/X   $BOOT_DIR/etc/X11/X.org
  ln -sf /usr/X11R6/bin/XF86_FBDev  $BOOT_DIR/etc/X11/X             

fi